@@ -17,11 +17,14 @@ def c():
     )
 
 
-def qt5():
+def qt5(console: bool = False):
     render_templates(
         "qt5",
+        include_suffixes=[".console"] if console else [".gui"],
         folders=[
+            "cmake-build-debug",
             "include",
             "lib",
         ],
+        common=False,
     )
